@@ -858,7 +858,7 @@ internet_address_list_prepend (InternetAddressList *list, InternetAddressList *p
 	src = ((char *) list->array->pdata);
 	dest = src + (sizeof (void *) * len);
 	
-	g_memmove (dest, src, (sizeof (void *) * list->array->len));
+	memmove (dest, src, (sizeof (void *) * list->array->len));
 	
 	for (i = 0; i < prepend->array->len; i++) {
 		ia = (InternetAddress *) prepend->array->pdata[i];
@@ -930,7 +930,7 @@ internet_address_list_insert (InternetAddressList *list, int index, InternetAddr
 		src = ((char *) list->array->pdata) + (sizeof (void *) * index);
 		n = list->array->len - index - 1;
 		
-		g_memmove (dest, src, (sizeof (void *) * n));
+		memmove (dest, src, (sizeof (void *) * n));
 		list->array->pdata[index] = ia;
 	} else {
 		/* the easy case */
@@ -2050,6 +2050,9 @@ address_parse (GMimeParserOptions *options, AddressParserFlags flags, const char
 	}
 	
  error:
+	if (g_mime_parser_options_get_warning_callback (options) != NULL)
+		_g_mime_parser_options_warn (options, offset, GMIME_WARN_INVALID_ADDRESS_LIST, *in);
+	
 	*address = NULL;
 	*in = inptr;
 	
@@ -2059,6 +2062,7 @@ address_parse (GMimeParserOptions *options, AddressParserFlags flags, const char
 static gboolean
 address_list_parse (InternetAddressList *list, GMimeParserOptions *options, const char **in, gboolean is_group, gint64 offset)
 {
+	gboolean can_warn = g_mime_parser_options_get_warning_callback (options) != NULL;
 	InternetAddress *address;
 	const char *charset;
 	const char *inptr;
@@ -2072,6 +2076,8 @@ address_list_parse (InternetAddressList *list, GMimeParserOptions *options, cons
 		return FALSE;
 	
 	while (*inptr) {
+		gboolean separator_between_addrs = FALSE;
+
 		if (is_group && *inptr ==  ';')
 			break;
 		
@@ -2086,6 +2092,9 @@ address_list_parse (InternetAddressList *list, GMimeParserOptions *options, cons
 			
 			if (charset)
 				address->charset = g_strdup (charset);
+
+			if (INTERNET_ADDRESS_IS_GROUP(address))
+				separator_between_addrs = TRUE;
 		}
 		
 		/* Note: we loop here in case there are any null addresses between commas */
@@ -2099,8 +2108,12 @@ address_list_parse (InternetAddressList *list, GMimeParserOptions *options, cons
 			if (*inptr != ',')
 				break;
 			
+			separator_between_addrs = TRUE;
 			inptr++;
 		} while (TRUE);
+		
+		if (can_warn && !(separator_between_addrs || (*inptr == '\0') || (is_group && *inptr == ';')))
+			_g_mime_parser_options_warn (options, offset, GMIME_WARN_INVALID_ADDRESS_LIST, *in);
 	}
 	
 	*in = inptr;
