@@ -41,7 +41,7 @@
 #define TEST_PRESERVE_HEADERS
 //#define PRINT_MIME_STRUCT
 #define PRINT_MIME_STRUCT_ITER
-//#define TEST_WRITE_TO_STREAM
+#define TEST_WRITE_TO_STREAM
 
 #ifdef PRINT_MIME_STRUCT
 static void
